# jsw-env-loader
> Python env loader.

## installation
```shell
pip install jsw-env-loader -U
```

## usage
> Run `python _examples/app.py` to see the output.

```python
from jsw_env_loader.env_loader import load_env

config = load_env()

def main():
    print(f'App config: {config}')

if __name__ == "__main__":
    main()
```
